@@ -23,7 +23,9 @@ class FileDiskRepository(FileRepository):
                 raise ValueError(f"{path} is not a file!")
 
         if len(extensions_to_get) == 0:
-            raise ValueError(f"{extensions_to_get} extensions list cannot be empty!")
+            raise ValueError(
+                f"{extensions_to_get} extensions list cannot be empty!"
+            )
 
         self.skip_hidden = skip_hidden
         self.files = files
@@ -69,7 +71,7 @@ class FileDiskRepository(FileRepository):
             self.header_path.parent,
             f"{self.header_path.stem}{self.header_path.suffix}",
             relative=False,
-            skip_hidden=self.skip_hidden,
+            skip_hidden=False,
         )
         if len(files) == 0:
             return None
