@@ -39,6 +39,7 @@ class Cli:
             header_path=Path(parsed_args.header_path),
             file_extensions=parsed_args.extensions,
             skip_hidden=parsed_args.skip_hidden,
+            prefer_multiline_comment=parsed_args.prefer_multiline_comment,
             debug=parsed_args.debug,
         )
 
@@ -58,7 +59,9 @@ class Cli:
 
         return run_fun(files_to_change, header_file)
 
-    def add_header_flow(self, files_to_change: List[Path], header_path: Path) -> int:
+    def add_header_flow(
+        self, files_to_change: List[Path], header_path: Path
+    ) -> int:
 
         return self.app.add_header_to_files(
             files_to_change=files_to_change, header_path=header_path
@@ -67,7 +70,9 @@ class Cli:
         # if not success:
         #     raise ValueError(f"failed to add header to files, see previous logs")
 
-    def remove_header_flow(self, files_to_change: List[Path], header_path: Path) -> int:
+    def remove_header_flow(
+        self, files_to_change: List[Path], header_path: Path
+    ) -> int:
 
         return self.app.remove_header_from_files(
             files_to_change=files_to_change, header_path=header_path
@@ -114,6 +119,13 @@ class Cli:
             required=True,
         )
 
+        parser.add_argument(
+            "--prefer-multiline-comment",
+            help=("Some languages support multiline and single line comments"),
+            action="store_true",
+            default=False,
+        )
+
         parser.add_argument(
             "--skip-hidden",
             help="adding header to hidden files",
